Parameters and distributions
============================

This page describes the format of the expected model parameters and distributions.

Model parameters
----------------

.. jsonschema:: ../../diameter_synthesis/schemas/model_params.json
    :lift_definitions:
    :auto_reference:
    :auto_target:


Distributions
-------------

.. jsonschema:: ../../diameter_synthesis/schemas/config.json
    :lift_definitions:
    :auto_reference:
    :auto_target:
